@@ -4,10 +4,8 @@ from .event import Event
 
 
 class Entity():
-    id: UUID
-    events: list[Event]
 
-    def __init__(self) -> None:
+    def __init__(self):
         self.id = uuid4()
         self.events = []
 
